@@ -3,21 +3,7 @@
  * Copyright (C) 2014-2016 Richard Hughes <richard@hughsie.com>
  * Copyright (C) 2016 Alexander Larsson <alexl@redhat.com>
  *
- * Licensed under the GNU General Public License Version 2
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ * SPDX-License-Identifier: GPL-2.0+
  */
 
 #include "config.h"
@@ -96,9 +82,7 @@ add_icons (AsApp *app,
 	pixbuf = g_object_ref (as_image_get_pixbuf (im));
 
 	/* save in target directory */
-	name = g_strdup_printf ("%ix%i/%s.png",
-				64, 64,
-				as_app_get_id_filename (AS_APP (app)));
+	name = g_strdup_printf ("%s.png", as_app_get_id_filename (AS_APP (app)));
 
 	icon = as_icon_new ();
 	as_icon_set_pixbuf (icon, pixbuf);
@@ -107,7 +91,7 @@ add_icons (AsApp *app,
 	as_icon_set_prefix (icon, as_app_get_icon_path (AS_APP (app)));
 	as_app_add_icon (AS_APP (app), icon);
 
-	icon_path = g_build_filename (icons_dir, name, NULL);
+	icon_path = g_build_filename (icons_dir, "64x64", name, NULL);
 
 	icon_subdir = g_path_get_dirname (icon_path);
 	if (g_mkdir_with_parents (icon_subdir, 0755)) {
@@ -154,9 +138,7 @@ add_icons (AsApp *app,
 	as_app_add_kudo_kind (AS_APP (app), AS_KUDO_KIND_HI_DPI_ICON);
 
 	/* save icon */
-	name_hidpi = g_strdup_printf ("%ix%i/%s.png",
-				      128, 128,
-				      as_app_get_id_filename (AS_APP (app)));
+	name_hidpi = g_strdup_printf ("%s.png", as_app_get_id_filename (AS_APP (app)));
 	icon_hidpi = as_icon_new ();
 	as_icon_set_pixbuf (icon_hidpi, pixbuf_hidpi);
 	as_icon_set_name (icon_hidpi, name_hidpi);
@@ -164,7 +146,7 @@ add_icons (AsApp *app,
 	as_icon_set_prefix (icon_hidpi, as_app_get_icon_path (AS_APP (app)));
 	as_app_add_icon (AS_APP (app), icon_hidpi);
 
-	icon_path_hidpi = g_build_filename (icons_dir, name_hidpi, NULL);
+	icon_path_hidpi = g_build_filename (icons_dir, "128x128", name_hidpi, NULL);
 	icon_subdir_hidpi = g_path_get_dirname (icon_path_hidpi);
 	if (g_mkdir_with_parents (icon_subdir_hidpi, 0755)) {
 		int errsv = errno;
