@@ -2,21 +2,7 @@
  *
  * Copyright (C) 2014-2015 Richard Hughes <richard@hughsie.com>
  *
- * Licensed under the GNU Lesser General Public License Version 2.1
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * SPDX-License-Identifier: LGPL-2.1+
  */
 
 /**
@@ -459,7 +445,8 @@ asb_context_add_filename (AsbContext *ctx, const gchar *filename, GError **error
 		pkg = asb_package_rpm_new ();
 #endif
 #ifdef HAVE_ALPM
-	if (g_str_has_suffix (filename, ".pkg.tar.xz"))
+	if (g_str_has_suffix (filename, ".pkg.tar") ||
+	    g_str_has_suffix (filename, ".pkg.tar.xz"))
 		pkg = asb_package_alpm_new ();
 #endif
 	if (g_str_has_suffix (filename, ".cab"))
@@ -852,8 +839,6 @@ asb_context_detect_missing_parents (AsbContext *ctx, GError **error)
 			continue;
 		if (as_app_get_pkgname_default (app) == NULL)
 			continue;
-		if (as_app_get_kind (app) != AS_APP_KIND_DESKTOP)
-			continue;
 		g_hash_table_insert (hash,
 				     (gpointer) as_app_get_id (app),
 				     app);
