@@ -2,21 +2,7 @@
  *
  * Copyright (C) 2014 Richard Hughes <richard@hughsie.com>
  *
- * Licensed under the GNU Lesser General Public License Version 2.1
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * SPDX-License-Identifier: LGPL-2.1+
  */
 
 /**
@@ -46,7 +32,7 @@ asb_package_cab_open (AsbPackage *pkg, const gchar *filename, GError **error)
 	g_set_error (error,
 		     AS_STORE_ERROR,
 		     AS_STORE_ERROR_FAILED,
-		     "Loading firmware is no longer suported, see fwupd");
+		     "Loading firmware is no longer supported, see fwupd");
 	return FALSE;
 }
 
@@ -58,7 +44,7 @@ asb_package_cab_ensure (AsbPackage *pkg,
 	g_set_error (error,
 		     AS_STORE_ERROR,
 		     AS_STORE_ERROR_FAILED,
-		     "Loading firmware is no longer suported, see fwupd");
+		     "Loading firmware is no longer supported, see fwupd");
 	return FALSE;
 }
 
