@@ -836,12 +836,14 @@ as_app_validate_release (AsApp *app,
 	guint number_para_max = 10;
 	guint number_para_min = 1;
 	gboolean required_timestamp = TRUE;
+	gboolean required_past_timestamp = TRUE;
 	const guint64 MAX_TZ_OFFSET = 14 * 60 * 60; /* UTC+14 is the biggest offset */
 
 	/* relax the requirements a bit */
 	if ((helper->flags & AS_APP_VALIDATE_FLAG_RELAX) > 0) {
 		number_para_max = 20;
 		required_timestamp = FALSE;
+		required_past_timestamp = FALSE;
 	}
 
 	/* make the requirements more strict */
@@ -871,7 +873,7 @@ as_app_validate_release (AsApp *app,
 	}
 
 	/* check the timestamp is not in the future */
-	if (timestamp > (guint64) g_get_real_time () / G_USEC_PER_SEC + MAX_TZ_OFFSET) {
+	if (required_past_timestamp && timestamp > (guint64) g_get_real_time () / G_USEC_PER_SEC + MAX_TZ_OFFSET) {
 		ai_app_validate_add (helper,
 				     AS_PROBLEM_KIND_ATTRIBUTE_INVALID,
 				     "<release> timestamp is in the future");
@@ -1177,6 +1179,35 @@ as_app_validate_check_id (AsAppValidateHelper *helper, const gchar *id)
 	}
 }
 
+static void
+as_app_validate_launchables (AsApp *app, AsAppValidateHelper *helper)
+{
+	GPtrArray *launchables = as_app_get_launchables (app);
+
+	/* launchable isn't required */
+	if (launchables == NULL)
+		return;
+
+	/* check each launchable in the file */
+	for (guint j = 0; j < launchables->len; j++) {
+		AsLaunchable *tmp = g_ptr_array_index (launchables, j);
+
+		if (as_launchable_get_kind (tmp) == AS_LAUNCHABLE_KIND_UNKNOWN) {
+			ai_app_validate_add (helper,
+			     AS_PROBLEM_KIND_ATTRIBUTE_INVALID,
+			     "<launchable> has invalid type attribute");
+			continue;
+		}
+
+		if (as_launchable_get_value (tmp) == NULL) {
+			ai_app_validate_add (helper,
+			     AS_PROBLEM_KIND_VALUE_MISSING,
+			     "<launchable> missing value");
+			continue;
+		}
+	}
+}
+
 /**
  * as_app_validate:
  * @app: a #AsApp instance.
@@ -1588,6 +1619,9 @@ as_app_validate (AsApp *app, guint32 flags, GError **error)
 	/* icons */
 	as_app_validate_icons (app, helper);
 
+	/* launchables */
+	as_app_validate_launchables (app, helper);
+
 	/* releases */
 	if (!as_app_validate_releases (app, helper, error))
 		return NULL;
