@@ -2,21 +2,7 @@
  *
  * Copyright (C) 2014-2016 Richard Hughes <richard@hughsie.com>
  *
- * Licensed under the GNU Lesser General Public License Version 2.1
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA
+ * SPDX-License-Identifier: LGPL-2.1+
  */
 
 /**
@@ -95,6 +81,12 @@ as_url_kind_to_string (AsUrlKind url_kind)
 		return as_ref_string_new_static ("missing");
 	if (url_kind == AS_URL_KIND_TRANSLATE)
 		return as_ref_string_new_static ("translate");
+	if (url_kind == AS_URL_KIND_DETAILS)
+		return as_ref_string_new_static ("details");
+	if (url_kind == AS_URL_KIND_SOURCE)
+		return as_ref_string_new_static ("source");
+	if (url_kind == AS_URL_KIND_CONTACT)
+		return as_ref_string_new_static ("contact");
 	return as_ref_string_new_static ("unknown");
 }
 
@@ -125,6 +117,12 @@ as_url_kind_from_string (const gchar *url_kind)
 		return AS_URL_KIND_MISSING;
 	if (g_strcmp0 (url_kind, "translate") == 0)
 		return AS_URL_KIND_TRANSLATE;
+	if (g_strcmp0 (url_kind, "details") == 0)
+		return AS_URL_KIND_DETAILS;
+	if (g_strcmp0 (url_kind, "source") == 0)
+		return AS_URL_KIND_SOURCE;
+	if (g_strcmp0 (url_kind, "contact") == 0)
+		return AS_URL_KIND_CONTACT;
 	return AS_URL_KIND_UNKNOWN;
 }
 
