@@ -2,21 +2,7 @@
  *
  * Copyright (C) 2014-2016 Richard Hughes <richard@hughsie.com>
  *
- * Licensed under the GNU Lesser General Public License Version 2.1
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA
+ * SPDX-License-Identifier: LGPL-2.1+
  */
 
 /**
@@ -148,6 +134,7 @@ AsScreenshotKind
 as_screenshot_get_kind (AsScreenshot *screenshot)
 {
 	AsScreenshotPrivate *priv = GET_PRIVATE (screenshot);
+	g_return_val_if_fail (AS_IS_SCREENSHOT (screenshot), AS_SCREENSHOT_KIND_UNKNOWN);
 	return priv->kind;
 }
 
@@ -165,6 +152,7 @@ gint
 as_screenshot_get_priority (AsScreenshot *screenshot)
 {
 	AsScreenshotPrivate *priv = GET_PRIVATE (screenshot);
+	g_return_val_if_fail (AS_IS_SCREENSHOT (screenshot), 0);
 	return priv->priority;
 }
 
@@ -182,6 +170,7 @@ GPtrArray *
 as_screenshot_get_images (AsScreenshot *screenshot)
 {
 	AsScreenshotPrivate *priv = GET_PRIVATE (screenshot);
+	g_return_val_if_fail (AS_IS_SCREENSHOT (screenshot), NULL);
 	return priv->images;
 }
 
@@ -205,6 +194,8 @@ as_screenshot_get_images_for_locale (AsScreenshot *screenshot,
 	GPtrArray *array;
 	guint i;
 
+	g_return_val_if_fail (AS_IS_SCREENSHOT (screenshot), NULL);
+
 	/* user wants a specific locale */
 	array = g_ptr_array_new_with_free_func ((GDestroyNotify) g_object_unref);
 	for (i = 0; i < priv->images->len; i++) {
@@ -303,6 +294,8 @@ as_screenshot_get_source (AsScreenshot *screenshot)
 	AsScreenshotPrivate *priv = GET_PRIVATE (screenshot);
 	guint i;
 
+	g_return_val_if_fail (AS_IS_SCREENSHOT (screenshot), NULL);
+
 	for (i = 0; i < priv->images->len; i++) {
 		im = g_ptr_array_index (priv->images, i);
 		if (as_image_get_kind (im) == AS_IMAGE_KIND_SOURCE)
@@ -326,6 +319,7 @@ const gchar *
 as_screenshot_get_caption (AsScreenshot *screenshot, const gchar *locale)
 {
 	AsScreenshotPrivate *priv = GET_PRIVATE (screenshot);
+	g_return_val_if_fail (AS_IS_SCREENSHOT (screenshot), NULL);
 	if (priv->captions == NULL)
 		return NULL;
 	return as_hash_lookup_by_locale (priv->captions, locale);
@@ -344,6 +338,7 @@ void
 as_screenshot_set_priority (AsScreenshot *screenshot, gint priority)
 {
 	AsScreenshotPrivate *priv = GET_PRIVATE (screenshot);
+	g_return_if_fail (AS_IS_SCREENSHOT (screenshot));
 	priv->priority = priority;
 }
 
@@ -360,6 +355,7 @@ void
 as_screenshot_set_kind (AsScreenshot *screenshot, AsScreenshotKind kind)
 {
 	AsScreenshotPrivate *priv = GET_PRIVATE (screenshot);
+	g_return_if_fail (AS_IS_SCREENSHOT (screenshot));
 	priv->kind = kind;
 }
 
@@ -376,6 +372,7 @@ void
 as_screenshot_add_image (AsScreenshot *screenshot, AsImage *image)
 {
 	AsScreenshotPrivate *priv = GET_PRIVATE (screenshot);
+	g_return_if_fail (AS_IS_SCREENSHOT (screenshot));
 	g_ptr_array_add (priv->images, g_object_ref (image));
 }
 
@@ -395,6 +392,7 @@ as_screenshot_set_caption (AsScreenshot *screenshot,
 			   const gchar *caption)
 {
 	AsScreenshotPrivate *priv = GET_PRIVATE (screenshot);
+	g_return_if_fail (AS_IS_SCREENSHOT (screenshot));
 	if (locale == NULL)
 		locale = "C";
 	as_screenshot_ensure_captions (screenshot);
@@ -425,6 +423,8 @@ as_screenshot_node_insert (AsScreenshot *screenshot,
 	GNode *n;
 	guint i;
 
+	g_return_val_if_fail (AS_IS_SCREENSHOT (screenshot), NULL);
+
 	/* nothing to add */
 	if (priv->images->len == 0)
 		return NULL;
@@ -477,6 +477,8 @@ as_screenshot_node_parse (AsScreenshot *screenshot, GNode *node,
 	gint priority;
 	g_autoptr(GHashTable) captions = NULL;
 
+	g_return_val_if_fail (AS_IS_SCREENSHOT (screenshot), FALSE);
+
 	tmp = as_node_get_attribute (node, "type");
 	if (tmp != NULL) {
 		as_screenshot_set_kind (screenshot,
@@ -601,6 +603,9 @@ as_screenshot_equal (AsScreenshot *screenshot1, AsScreenshot *screenshot2)
 	AsImage *im1;
 	AsImage *im2;
 
+	g_return_val_if_fail (AS_IS_SCREENSHOT (screenshot1), FALSE);
+	g_return_val_if_fail (AS_IS_SCREENSHOT (screenshot2), FALSE);
+
 	/* trivial */
 	if (screenshot1 == screenshot2)
 		return TRUE;
