@@ -2,21 +2,7 @@
  *
  * Copyright (C) 2014 Richard Hughes <richard@hughsie.com>
  *
- * Licensed under the GNU Lesser General Public License Version 2.1
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA
+ * SPDX-License-Identifier: LGPL-2.1+
  */
 
 #include "config.h"
@@ -195,7 +181,7 @@ as_yaml_node_get_kind (AsNode *node)
 }
 
 static AsYamlNode *
-as_yaml_node_new (AsYamlNodeKind kind, const gchar *id)
+as_yaml_node_new (AsYamlNodeKind kind, AsRefString *id)
 {
 	AsYamlNode *ym;
 	ym = g_slice_new0 (AsYamlNode);
@@ -371,12 +357,12 @@ as_node_yaml_process_layer (AsYamlContext *ctx, AsNode *parent, GError **error)
 			    last_scalar != NULL) {
 				ym = last_scalar->data;
 				if (ym->key != NULL)
-					ym->value = as_ref_string_new_copy (tmp);
+					ym->value = as_ref_string_new (tmp);
 				ym->kind = AS_YAML_NODE_KIND_KEY_VALUE;
 				last_scalar = NULL;
 			} else {
 				if (as_yaml_node_valid (ctx, parent, tmp)) {
-					g_autoptr(AsRefString) rstr = as_ref_string_new_copy (tmp);
+					g_autoptr(AsRefString) rstr = as_ref_string_new (tmp);
 					ym = as_yaml_node_new (AS_YAML_NODE_KIND_KEY, rstr);
 				} else {
 					ym = as_yaml_node_new (AS_YAML_NODE_KIND_KEY, NULL);
